@@ -2,7 +2,7 @@ from pypi_simple import __version__
 
 project = "pypi-simple"
 author = "John T. Wodder II"
-copyright = "2018-2021 John T. Wodder II"
+copyright = "2018-2022 John T. Wodder II"
 
 extensions = [
     "sphinx.ext.autodoc",
@@ -19,7 +19,7 @@ autodoc_member_order = "bysource"
 
 intersphinx_mapping = {
     "python": ("https://docs.python.org/3", None),
-    "requests": ("https://requests.readthedocs.io/en/master/", None),
+    "requests": ("https://requests.readthedocs.io/en/latest/", None),
 }
 
 exclude_patterns = ["_build"]
