@@ -14,7 +14,7 @@ Visit <https://github.com/jwodder/pypi-simple> or <https://pypi-simple.rtfd.io>
 for more information.
 """
 
-__version__ = "0.10.0"
+__version__ = "1.0.0"
 __author__ = "John Thorvald Wodder II"
 __author_email__ = "pypi-simple@varonathe.org"
 __license__ = "MIT"
@@ -26,28 +26,61 @@ PYPI_SIMPLE_ENDPOINT: str = "https://pypi.org/simple/"
 #: The maximum supported simple repository version (See :pep:`629`)
 SUPPORTED_REPOSITORY_VERSION: str = "1.0"
 
-from .classes import DistributionPackage, IndexPage, Link, ProjectPage
-from .client import PyPISimple
-from .filenames import parse_filename
-from .parse_old import parse_links, parse_project_page, parse_simple_index
-from .parse_repo import (
-    parse_repo_index_json,
-    parse_repo_index_page,
-    parse_repo_index_response,
-    parse_repo_links,
-    parse_repo_project_json,
-    parse_repo_project_page,
-    parse_repo_project_response,
+#: :mailheader:`Accept` header value for accepting either the HTML or JSON
+#: serialization without a preference
+ACCEPT_ANY: str = ", ".join(
+    [
+        "application/vnd.pypi.simple.v1+json",
+        "application/vnd.pypi.simple.v1+html",
+        "text/html;q=0.01",
+    ]
 )
-from .parse_stream import parse_links_stream, parse_links_stream_response
-from .progress import ProgressTracker, tqdm_progress_factory
-from .util import (
+
+#: :mailheader:`Accept` header value for accepting only the JSON serialization
+ACCEPT_JSON_ONLY = "application/vnd.pypi.simple.v1+json"
+
+#: :mailheader:`Accept` header value for accepting only the HTML serialization
+ACCEPT_HTML_ONLY = ", ".join(
+    [
+        "application/vnd.pypi.simple.v1+html",
+        "text/html;q=0.01",
+    ]
+)
+
+#: :mailheader:`Accept` header value for accepting either the HTML or JSON
+#: serialization with a preference for JSON
+ACCEPT_JSON_PREFERRED = ", ".join(
+    [
+        "application/vnd.pypi.simple.v1+json",
+        "application/vnd.pypi.simple.v1+html;q=0.5",
+        "text/html;q=0.01",
+    ]
+)
+
+#: :mailheader:`Accept` header value for accepting either the HTML or JSON
+#: serialization with a preference for HTML
+ACCEPT_HTML_PREFERRED = ", ".join(
+    [
+        "application/vnd.pypi.simple.v1+html",
+        "text/html;q=0.5",
+        "application/vnd.pypi.simple.v1+json;q=0.1",
+    ]
+)
+
+from .classes import DistributionPackage, IndexPage, ProjectPage
+from .client import NoSuchProjectError, PyPISimple
+from .errors import (
     DigestMismatchError,
     NoDigestsError,
     UnexpectedRepoVersionWarning,
+    UnparsableFilenameError,
     UnsupportedContentTypeError,
     UnsupportedRepoVersionError,
 )
+from .filenames import parse_filename
+from .html import Link, RepositoryPage
+from .html_stream import parse_links_stream, parse_links_stream_response
+from .progress import ProgressTracker, tqdm_progress_factory
 
 __all__ = [
     "DigestMismatchError",
@@ -55,26 +88,19 @@ __all__ = [
     "IndexPage",
     "Link",
     "NoDigestsError",
+    "NoSuchProjectError",
     "PYPI_SIMPLE_ENDPOINT",
     "ProgressTracker",
     "ProjectPage",
     "PyPISimple",
+    "RepositoryPage",
     "SUPPORTED_REPOSITORY_VERSION",
     "UnexpectedRepoVersionWarning",
+    "UnparsableFilenameError",
     "UnsupportedContentTypeError",
     "UnsupportedRepoVersionError",
     "parse_filename",
-    "parse_links",
     "parse_links_stream",
     "parse_links_stream_response",
-    "parse_project_page",
-    "parse_repo_index_json",
-    "parse_repo_index_page",
-    "parse_repo_index_response",
-    "parse_repo_links",
-    "parse_repo_project_json",
-    "parse_repo_project_page",
-    "parse_repo_project_response",
-    "parse_simple_index",
     "tqdm_progress_factory",
 ]
