@@ -1,15 +1,17 @@
+from __future__ import annotations
+from collections.abc import Callable, Iterator
 import os
 from pathlib import Path
 import platform
 from types import TracebackType
-from typing import Any, AnyStr, Callable, Iterator, List, Optional, Tuple, Type, Union
-from warnings import warn
+from typing import Any, AnyStr, Optional
+from mailbits import ContentType
 from packaging.utils import canonicalize_name as normalize
 import requests
-from . import PYPI_SIMPLE_ENDPOINT, __url__, __version__
+from . import ACCEPT_ANY, PYPI_SIMPLE_ENDPOINT, __url__, __version__
 from .classes import DistributionPackage, IndexPage, ProjectPage
-from .parse_repo import parse_repo_index_response, parse_repo_project_response
-from .parse_stream import parse_links_stream_response
+from .errors import UnsupportedContentTypeError
+from .html_stream import parse_links_stream_response
 from .progress import ProgressTracker, null_progress_tracker
 from .util import AbstractDigestChecker, DigestChecker, NullDigestChecker
 
@@ -23,21 +25,6 @@ USER_AGENT: str = "pypi-simple/{} ({}) requests/{} {}/{}".format(
     platform.python_version(),
 )
 
-ACCEPT = ", ".join(
-    [
-        "application/vnd.pypi.simple.v1+json",
-        "application/vnd.pypi.simple.v1+html",
-        "text/html;q=0.01",
-    ]
-)
-
-ACCEPT_HTML = ", ".join(
-    [
-        "application/vnd.pypi.simple.v1+html",
-        "text/html;q=0.01",
-    ]
-)
-
 
 class PyPISimple:
     """
@@ -58,14 +45,9 @@ class PyPISimple:
     automatically close its session on exit, regardless of where the session
     object came from.
 
-    .. versionchanged:: 0.8.0
-        Now usable as a context manager
+    .. versionchanged:: 1.0.0
 
-    .. versionchanged:: 0.5.0
-        ``session`` argument added
-
-    .. versionchanged:: 0.4.0
-        ``auth`` argument added
+        ``accept`` parameter added
 
     :param str endpoint: The base URL of the simple API instance to query;
         defaults to the base URL for PyPI's simple API
@@ -77,6 +59,11 @@ class PyPISimple:
 
     :param session: Optional `requests.Session` object to use instead of
         creating a fresh one
+
+    :param str accept:
+        The :mailheader:`Accept` header to send in requests in order to specify
+        what serialization format the server should return; defaults to
+        `ACCEPT_ANY`
     """
 
     def __init__(
@@ -84,6 +71,7 @@ class PyPISimple:
         endpoint: str = PYPI_SIMPLE_ENDPOINT,
         auth: Any = None,
         session: Optional[requests.Session] = None,
+        accept: str = ACCEPT_ANY,
     ) -> None:
         self.endpoint: str = endpoint.rstrip("/") + "/"
         self.s: requests.Session
@@ -94,13 +82,14 @@ class PyPISimple:
             self.s.headers["User-Agent"] = USER_AGENT
         if auth is not None:
             self.s.auth = auth
+        self.accept = accept
 
-    def __enter__(self) -> "PyPISimple":
+    def __enter__(self) -> PyPISimple:
         return self
 
     def __exit__(
         self,
-        _exc_type: Optional[Type[BaseException]],
+        _exc_type: Optional[type[BaseException]],
         _exc_val: Optional[BaseException],
         _exc_tb: Optional[TracebackType],
     ) -> None:
@@ -108,11 +97,10 @@ class PyPISimple:
 
     def get_index_page(
         self,
-        timeout: Union[float, Tuple[float, float], None] = None,
+        timeout: float | tuple[float, float] | None = None,
+        accept: Optional[str] = None,
     ) -> IndexPage:
         """
-        .. versionadded:: 0.7.0
-
         Fetches the index/root page from the simple repository and returns an
         `IndexPage` instance.
 
@@ -121,8 +109,16 @@ class PyPISimple:
             PyPI's project index file is very large and takes several seconds
             to parse.  Use this method sparingly.
 
+        .. versionchanged:: 1.0.0
+
+            ``accept`` parameter added
+
         :param timeout: optional timeout to pass to the ``requests`` call
-        :type timeout: Union[float, Tuple[float,float], None]
+        :type timeout: float | tuple[float,float] | None
+        :param Optional[str] accept:
+            The :mailheader:`Accept` header to send in order to
+            specify what serialization format the server should return;
+            defaults to the value supplied on client instantiation
         :rtype: IndexPage
         :raises requests.HTTPError: if the repository responds with an HTTP
             error code
@@ -131,25 +127,26 @@ class PyPISimple:
         :raises UnsupportedRepoVersionError: if the repository version has a
             greater major component than the supported repository version
         """
-        r = self.s.get(self.endpoint, timeout=timeout, headers={"Accept": ACCEPT})
+        r = self.s.get(
+            self.endpoint, timeout=timeout, headers={"Accept": accept or self.accept}
+        )
         r.raise_for_status()
-        return parse_repo_index_response(r)
+        return IndexPage.from_response(r)
 
     def stream_project_names(
         self,
         chunk_size: int = 65535,
-        timeout: Union[float, Tuple[float, float], None] = None,
+        timeout: float | tuple[float, float] | None = None,
+        accept: Optional[str] = None,
     ) -> Iterator[str]:
         """
-        .. versionadded:: 0.7.0
-
         Returns a generator of names of projects available in the repository.
         The names are not normalized.
 
-        Unlike `get_index_page()` and `get_projects()`, this function makes a
-        streaming request to the server and parses the document in chunks.  It
-        is intended to be faster than the other methods, especially when the
-        complete document is very large.
+        Unlike `get_index_page()`, this function makes a streaming request to
+        the server and parses the document in chunks.  It is intended to be
+        faster than the other methods, especially when the complete document is
+        very large.
 
         .. warning::
 
@@ -157,41 +154,82 @@ class PyPISimple:
             support for web encodings, encoding detection, or handling invalid
             HTML.
 
+        .. note::
+
+            If the server responds with a JSON representation of the Simple API
+            rather than an HTML representation, the response body will be
+            loaded & parsed in its entirety before yielding anything.
+
+        .. versionchanged:: 1.0.0
+
+            ``accept`` parameter added
+
         :param int chunk_size: how many bytes to read from the response at a
             time
         :param timeout: optional timeout to pass to the ``requests`` call
-        :type timeout: Union[float, Tuple[float,float], None]
+        :type timeout: float | tuple[float,float] | None
+        :param Optional[str] accept:
+            The :mailheader:`Accept` header to send in order to
+            specify what serialization format the server should return;
+            defaults to the value supplied on client instantiation
         :rtype: Iterator[str]
         :raises requests.HTTPError: if the repository responds with an HTTP
             error code
+        :raises UnsupportedContentTypeError: if the repository responds with an
+            unsupported :mailheader:`Content-Type`
         :raises UnsupportedRepoVersionError: if the repository version has a
             greater major component than the supported repository version
         """
         with self.s.get(
-            self.endpoint, stream=True, timeout=timeout, headers={"Accept": ACCEPT_HTML}
+            self.endpoint,
+            stream=True,
+            timeout=timeout,
+            headers={"Accept": accept or self.accept},
         ) as r:
             r.raise_for_status()
-            for link in parse_links_stream_response(r, chunk_size):
-                yield link.text
+            ct = ContentType.parse(r.headers.get("content-type", "text/html"))
+            if ct.content_type == "application/vnd.pypi.simple.v1+json":
+                page = IndexPage.from_json_data(r.json())
+                yield from page.projects
+            elif (
+                ct.content_type == "application/vnd.pypi.simple.v1+html"
+                or ct.content_type == "text/html"
+            ):
+                for link in parse_links_stream_response(r, chunk_size):
+                    yield link.text
+            else:
+                raise UnsupportedContentTypeError(r.url, str(ct))
 
     def get_project_page(
         self,
         project: str,
-        timeout: Union[float, Tuple[float, float], None] = None,
-    ) -> Optional[ProjectPage]:
+        timeout: float | tuple[float, float] | None = None,
+        accept: Optional[str] = None,
+    ) -> ProjectPage:
         """
-        .. versionadded:: 0.7.0
-
         Fetches the page for the given project from the simple repository and
-        returns a `ProjectPage` instance.  Returns `None` if the repository
-        responds with a 404.  All other HTTP errors cause a
+        returns a `ProjectPage` instance.  Raises `NoSuchProjectError` if the
+        repository responds with a 404.  All other HTTP errors cause a
         `requests.HTTPError` to be raised.
 
+        .. versionchanged:: 1.0.0
+
+            - A 404 now causes `NoSuchProjectError` to be raised instead of
+              returning `None`
+
+            - ``accept`` parameter added
+
         :param str project: The name of the project to fetch information on.
             The name does not need to be normalized.
         :param timeout: optional timeout to pass to the ``requests`` call
-        :type timeout: Union[float, Tuple[float,float], None]
-        :rtype: Optional[ProjectPage]
+        :type timeout: float | tuple[float,float] | None
+        :param Optional[str] accept:
+            The :mailheader:`Accept` header to send in order to
+            specify what serialization format the server should return;
+            defaults to the value supplied on client instantiation
+        :rtype: ProjectPage
+        :raises NoSuchProjectError: if the repository responds with a 404 error
+            code
         :raises requests.HTTPError: if the repository responds with an HTTP
             error code other than 404
         :raises UnsupportedContentTypeError: if the repository responds with an
@@ -200,11 +238,11 @@ class PyPISimple:
             greater major component than the supported repository version
         """
         url = self.get_project_url(project)
-        r = self.s.get(url, timeout=timeout, headers={"Accept": ACCEPT})
+        r = self.s.get(url, timeout=timeout, headers={"Accept": accept or None})
         if r.status_code == 404:
-            return None
+            raise NoSuchProjectError(project, url)
         r.raise_for_status()
-        return parse_repo_project_response(project, r)
+        return ProjectPage.from_response(r, project)
 
     def get_project_url(self, project: str) -> str:
         """
@@ -219,15 +257,13 @@ class PyPISimple:
     def download_package(
         self,
         pkg: DistributionPackage,
-        path: Union[AnyStr, "os.PathLike[AnyStr]"],
+        path: AnyStr | os.PathLike[AnyStr],
         verify: bool = True,
         keep_on_error: bool = False,
         progress: Optional[Callable[[Optional[int]], ProgressTracker]] = None,
-        timeout: Union[float, Tuple[float, float], None] = None,
+        timeout: float | tuple[float, float] | None = None,
     ) -> None:
         """
-        .. versionadded:: 0.10.0
-
         Download the given `DistributionPackage` to the given path.
 
         If an error occurs while downloading or verifying digests, and
@@ -249,9 +285,9 @@ class PyPISimple:
         :param bool keep_on_error:
             whether to keep (true) or delete (false) the downloaded file if an
             error occurs
-        :param progress: a callable for contructing a progress tracker
+        :param progress: a callable for constructing a progress tracker
         :param timeout: optional timeout to pass to the ``requests`` call
-        :type timeout: Union[float, Tuple[float,float], None]
+        :type timeout: float | tuple[float,float] | None
         :raises requests.HTTPError: if the repository responds with an HTTP
             error code
         :raises NoDigestsError:
@@ -292,64 +328,18 @@ class PyPISimple:
                         pass
                 raise
 
-    def get_projects(self) -> Iterator[str]:
-        """
-        Returns a generator of names of projects available in the repository.
-        The names are not normalized.
 
-        .. warning::
+class NoSuchProjectError(Exception):
+    """
+    Raised by `PyPISimple.get_project_page()` when a request for a project
+    fails with a 404 error code
+    """
 
-            PyPI's project index file is very large and takes several seconds
-            to parse.  Use this method sparingly.
+    def __init__(self, project: str, url: str) -> None:
+        #: The name of the project requested
+        self.project = project
+        #: The URL to which the failed request was made
+        self.url = url
 
-        .. deprecated:: 0.7.0
-            Use `get_index_page()` or `stream_project_names()` instead
-
-        :rtype: Iterator[str]
-        :raises requests.HTTPError: if the repository responds with an HTTP
-            error code
-        :raises UnsupportedContentTypeError: if the repository responds with an
-            unsupported :mailheader:`Content-Type`
-        :raises UnsupportedRepoVersionError: if the repository version has a
-            greater major component than the supported repository version
-        """
-        warn(
-            "The get_projects() method is deprecated.  Use get_index_page() or"
-            " stream_project_names() instead.",
-            DeprecationWarning,
-        )
-        page = self.get_index_page()
-        return iter(page.projects)
-
-    def get_project_files(self, project: str) -> List[DistributionPackage]:
-        """
-        Returns a list of `DistributionPackage` objects representing all of the
-        package files available in the repository for the given project.
-
-        When fetching the project's information from the repository, a 404
-        response is treated the same as an empty page, resulting in an empty
-        list.  All other HTTP errors cause a `requests.HTTPError` to be raised.
-
-        .. deprecated:: 0.7.0
-            Use `get_project_page()` instead
-
-        :param str project: The name of the project to fetch information on.
-            The name does not need to be normalized.
-        :rtype: List[DistributionPackage]
-        :raises requests.HTTPError: if the repository responds with an HTTP
-            error code other than 404
-        :raises UnsupportedContentTypeError: if the repository responds with an
-            unsupported :mailheader:`Content-Type`
-        :raises UnsupportedRepoVersionError: if the repository version has a
-            greater major component than the supported repository version
-        """
-        warn(
-            "The get_project_files() method is deprecated."
-            "  Use get_project_page() instead.",
-            DeprecationWarning,
-        )
-        page = self.get_project_page(project)
-        if page is None:
-            return []
-        else:
-            return page.packages
+    def __str__(self) -> str:
+        return f"No details about project {self.project!r} available at {self.url}"
